<?php

namespace Drupal\activitypub\Services;

use Drupal\activitypub\Entity\ActivityPubActorInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\user\UserInterface;
use Symfony\Component\HttpFoundation\Request;

interface ActivityPubUtilityInterface {

  /**
   * Returns the ActivityPub name.
   *
   * @param \Drupal\activitypub\Entity\ActivityPubActorInterface $actor
   *
   * @return string
   */
  public function getActivityPubName(ActivityPubActorInterface $actor);

  /**
   * Returns the ActivityPub ID based on the Actor.
   *
   * @param \Drupal\activitypub\Entity\ActivityPubActorInterface $actor
   *
   * @return string
   */
  public function getActivityPubID(ActivityPubActorInterface $actor);

  /**
   * Returns the user avatar, if any.
   *
   * @param \Drupal\user\UserInterface $user
   *
   * @return string
   */
  public function getActivityPubUserAvatar(UserInterface $user);

  /**
   * Get the ActivityPubServer.
   *
   * @param array $config
   *
   * @return \ActivityPhp\Server
   */
  public function getServer(array $config = []);

  /**
   * Alter the nodeinfo data.
   *
   * @param array $data
   */
  public function alterNodeInfo(array &$data);

  /**
   * Act on entity delete.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *
   * @return mixed
   */
  public function onEntityDelete(EntityInterface $entity);

  /**
   * Returns a collection of types to ignore for the outbox.
   *
   * @return array
   */
  public function getOutboxIgnoreTypes();

  /**
   * Returns a collection of types to include for timelines.
   *
   * @return array
   */
  public function getTimelineTypes();

  /**
   * Generate keys in a path.
   *
   * @param $path
   *
   * @return bool
   */
  public function generateKeys($path);

  /**
   * Delete keys.
   *
   * @param $path
   */
  public function deleteKeys($path);

  /**
   * Get the public key for a path.
   *
   * @param $path
   *
   * @return string
   */
  public function getPublicKey($path);

  /**
   * Get the private key for a path.
   *
   * @param $path
   *
   * @return string
   */
  public function getPrivateKey($path);

  /**
   * Create a signature.
   *
   * @param $private_key_path
   * @param $host
   * @param $path
   * @param $digest
   * @param null $date
   *
   * @return string
   */
  public function createSignature($private_key_path, $host, $path, $digest, $date = NULL);

  /**
   * Create a digest.
   *
   * @param $message
   *
   * @return string
   */
  public function createDigest($message);

  /**
   * Verify signature.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   * @param string $actor
   *
   * @return bool
   */
  public function verifySignature(Request $request, string $actor);

}
